import unittest

class TestSession(unittest.TestCase):
    def test_at_sync(self):
        # session = Session()
        # self.assertEqual(expected, session.at_sync())
        assert True # TODO: implement your test here

    def test_data_in(self):
        # session = Session()
        # self.assertEqual(expected, session.data_in(text, **kwargs))
        assert True # TODO: implement your test here

    def test_data_out(self):
        # session = Session()
        # self.assertEqual(expected, session.data_out(text, **kwargs))
        assert True # TODO: implement your test here

    def test_disconnect(self):
        # session = Session()
        # self.assertEqual(expected, session.disconnect(reason))
        assert True # TODO: implement your test here

    def test_get_sync_data(self):
        # session = Session()
        # self.assertEqual(expected, session.get_sync_data())
        assert True # TODO: implement your test here

    def test_init_session(self):
        # session = Session()
        # self.assertEqual(expected, session.init_session(protocol_key, address, sessionhandler))
        assert True # TODO: implement your test here

    def test_load_sync_data(self):
        # session = Session()
        # self.assertEqual(expected, session.load_sync_data(sessdata))
        assert True # TODO: implement your test here

if __name__ == '__main__':
    unittest.main()
